==> opencdk-0.3.1.tar.gz: opencdk-0.3.1/src/context.h <==
/* context.h
 *       Copyright (C) 2002 Timo Schulz
 *
 * This file is part of OpenCDK.
 *
 * OpenCDK is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * OpenCDK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenCDK; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef CDK_CONTEXT_H
#define CDK_CONTEXT_H

#include "types.h"


struct cdk_verify_result_s 
{
  int sig_status;
  u32 keyid[2];
  u32 created;
  u32 expires;
  int pubkey_algo;
  int digest_algo;
  char * notation;
};

struct cdk_handle_s 
{
  int cipher_algo;
  int digest_algo;
  int compress_algo;
  struct
  {
    int mode;
    int digest_algo;
    int cipher_algo;
  } s2k;
  struct 
  {
    unsigned armor:1;
    unsigned textmode:1;
    unsigned compress:1;
    unsigned mdc:1;
  } opt;
  struct 
  {
    Verify_Result verify;
  } result;
};

struct cdk_prefitem_s
{
  unsigned char type;
  unsigned char value;
};

struct cdk_subpkt_s
{
  struct cdk_subpkt_s * next;
  unsigned long size;
  unsigned char type;
  unsigned char d[1];  
};

struct cdk_mpi_s
{
  unsigned short bits;
  unsigned short bytes;
  unsigned char data[1];  
};

struct cdk_keydb_handle_s
{
  CDK_STREAM buf; /* NULL if the name item is valid */
  u32 old_offset;
  u32 offset;
  char * name;
  int type;
  int secret;
  int used;  
};

struct cdk_keydb_search_s
{
  union
  {
    const char * pattern;
    unsigned long keyid[2];
    unsigned char fpr[20];     
  }
  u;
  int type;  
};

struct cdk_key_list_s
{
  CDK_KEYLIST next;
  union
  {
    cdkPKT_public_key * pk;
    cdkPKT_secret_key * sk;
  }
  key;
  int mark;
  int type;  
};

struct cdk_dek_s
{
  int algo;
  int keylen;
  int use_mdc;
  unsigned char key[32]; /* 256-bit */
};

struct cdk_string_list 
{
  struct cdk_string_list * next;
  char d[1]; 
};

#endif /* CDK_CONTEXT_H */

==> opencdk-0.3.2.tar.gz: opencdk-0.3.2/src/context.h <==
/* context.h
 *       Copyright (C) 2002 Timo Schulz
 *
 * This file is part of OpenCDK.
 *
 * OpenCDK is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * OpenCDK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenCDK; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef CDK_CONTEXT_H
#define CDK_CONTEXT_H

#include "types.h"


struct cdk_verify_result_s 
{
  int sig_status;
  u32 keyid[2];
  u32 created;
  u32 expires;
  int pubkey_algo;
  int digest_algo;
  char * notation;
};

struct cdk_handle_s 
{
  int cipher_algo;
  int digest_algo;
  int compress_algo;
  struct
  {
    int mode;
    int digest_algo;
    int cipher_algo;
  } s2k;
  struct 
  {
    unsigned armor:1;
    unsigned textmode:1;
    unsigned compress:1;
    unsigned mdc:1;
  } opt;
  struct 
  {
    Verify_Result verify;
  } result;
};

struct cdk_prefitem_s
{
  unsigned char type;
  unsigned char value;
};

struct cdk_subpkt_s
{
  struct cdk_subpkt_s * next;
  unsigned long size;
  unsigned char type;
  unsigned char d[1];  
};

struct cdk_mpi_s
{
  unsigned short bits;
  unsigned short bytes;
  unsigned char data[1];  
};

struct cdk_keydb_handle_s
{
  CDK_STREAM buf; /* NULL if the name item is valid */
  u32 old_offset;
  u32 offset;
  char * name;
  int type;
  int secret;
  int used;  
};

struct cdk_keydb_search_s
{
  union
  {
    const char * pattern;
    unsigned long keyid[2];
    unsigned char fpr[20];     
  }
  u;
  int type;  
};

struct cdk_key_list_s
{
  CDK_KEYLIST next;
  union
  {
    cdkPKT_public_key * pk;
    cdkPKT_secret_key * sk;
  }
  key;
  int mark;
  int type;  
};

struct cdk_dek_s
{
  int algo;
  int keylen;
  int use_mdc;
  unsigned char key[32]; /* 256-bit */
};

struct cdk_string_list_s
{
  struct cdk_string_list_s * next;
  char d[1]; 
};

#endif /* CDK_CONTEXT_H */
